from setuptools import setup

setup(
    name='python-proto',
    version='100.100.100',    
    description='For questions reach out to security@plaid.com',
    url='https://www.plaid.com',
    author='Plaid',
    author_email='agupta@plaid.com',
    license='BSD 2-clause',
    packages=['python-proto'],
    install_requires=[],

    classifiers=[
    ],
)
